% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/allelic_series_sumstats.R
\name{ASBTSS}
\alias{ASBTSS}
\title{Allelic Series Burden Test from Summary Statistics}
\usage{
ASBTSS(
  anno,
  beta,
  se,
  check = TRUE,
  eps = 1,
  lambda = 1,
  ld = NULL,
  method = "none",
  return_beta = FALSE,
  weights = c(1, 2, 3)
)
}
\arguments{
\item{anno}{(snps x 1) annotation vector with integer values in 1 through
the number of annotation categories L.}

\item{beta}{(snps x 1) vector of effect sizes for the coding genetic variants
within a gene.}

\item{se}{(snps x 1) vector of standard errors for the effect sizes.}

\item{check}{Run input checks? Default: TRUE.}

\item{eps}{Epsilon added to the diagonal of the LD matrix if not positive
definite. Note, smaller values increase the chances of a false positive.}

\item{lambda}{Optional genomic inflation factor. Defaults to 1, which
results in no rescaling.}

\item{ld}{(snps x snps) matrix of correlations among the genetic variants.
Although ideally provided, an identity matrix is assumed if not.}

\item{method}{Method for aggregating across categories:
("none", "sum"). Default: "none".}

\item{return_beta}{Return the estimated effect size? Default: FALSE.}

\item{weights}{(L x 1) vector of annotation category weights. Note that the
number of annotation categories L is inferred from the length of \code{weights}.}
}
\value{
If \code{return_beta = TRUE}, a list of including the effect size
data.frame "betas" and the p-value "pval". If \code{return_beta = FALSE},
a numeric p-value.
}
\description{
Allelic series burden test from summary statistics.
}
\section{Notes}{

\itemize{
\item The allelic series burden does not require the minor allele frequencies.
}
}

\examples{
# Generate data.
data <- DGP(n = 1e3)
sumstats <- CalcSumstats(data = data)

# Run allelic series burden test from sumstats.
results <- ASBTSS(
  anno = sumstats$sumstats$anno,
  beta = sumstats$sumstats$beta, 
  se = sumstats$sumstats$se,
  ld = sumstats$ld
)
show(results)
}
